@@ -38,7 +38,7 @@
 
 // each structure has a pointer as a unique identifier that allows type checking at run time
 
-static const char *const liq_attr_magic = "liq_attr";
+const char *const liq_attr_magic = "liq_attr";
 static const char *const liq_image_magic = "liq_image";
 static const char *const liq_result_magic = "liq_result";
 static const char *const liq_remapping_result_magic = "liq_remapping_result";
@@ -65,6 +65,7 @@ static const char *const liq_freed_magic = "free";
     }
 #define CHECK_USER_POINTER(ptr) liq_crash_if_invalid_pointer_given(ptr)
 
+#if 0
 struct liq_attr
 {
     const char *magic_header;
@@ -83,6 +84,7 @@ struct liq_attr
     liq_log_flush_callback_function *log_flush_callback;
     void *log_flush_callback_user_info;
 };
+#endif /* 0*/
 
 struct liq_image
 {
@@ -877,12 +879,8 @@ static void liq_aligned_free(void *inptr)
 liq_attr* liq_attr_create_with_allocator(void* (*custom_malloc)(size_t), void (*custom_free)(void*))
 {
     if (!custom_malloc && !custom_free) {
-        custom_malloc = malloc;
-        custom_free = free;
-	/*
         custom_malloc = liq_aligned_malloc;
         custom_free = liq_aligned_free;
-	*/
     }
     else if (!custom_malloc != !custom_free) {
         return NULL; // either specify both or none
