@@ -114,6 +114,27 @@ int liq_get_quantization_quality(liq_result* result);
 
 liq_error liq_result_destroy(liq_result*);
 
+struct liq_attr
+{
+    const char *magic_header;
+    void* (*malloc)(size_t);
+    void (*free)(void*);
+
+    double target_mse, max_mse, voronoi_iteration_limit;
+    float min_opaque_val;
+    unsigned int max_colors, max_histogram_entries;
+    unsigned int min_posterization_output /* user setting */, min_posterization_input /* speed setting */;
+    unsigned int voronoi_iterations, feedback_loop_trials;
+    bool last_index_transparent, use_contrast_maps, use_dither_map, fast_palette;
+    unsigned int speed;
+    liq_log_callback_function *log_callback;
+    void *log_callback_user_info;
+    liq_log_flush_callback_function *log_flush_callback;
+    void *log_flush_callback_user_info;
+};
+
+    extern const char *const liq_attr_magic;
+
 #ifdef __cplusplus
 }
 #endif
